@@ -88,6 +88,8 @@ var api10 = []APIEndpoint{
 	networkACLCmd,
 	networkACLsCmd,
 	networkACLLogCmd,
+	networkAddressSetCmd,
+	networkAddressSetsCmd,
 	networkAllocationsCmd,
 	networkForwardCmd,
 	networkForwardsCmd,
@@ -795,6 +797,7 @@ func doApi10UpdateTriggers(d *Daemon, nodeChanged, clusterChanged map[string]str
 	oidcChanged := false
 	openFGAChanged := false
 	ovnChanged := false
+	linstorChanged := false
 	ovsChanged := false
 	syslogChanged := false
 	loggingChanges := map[string]struct{}{}
@@ -840,6 +843,16 @@ func doApi10UpdateTriggers(d *Daemon, nodeChanged, clusterChanged map[string]str
 
 		case "openfga.api.url", "openfga.api.token", "openfga.store.id":
 			openFGAChanged = true
+
+		case "storage.linstor.controller_connection", "storage.linstor.ca_cert", "storage.linstor.client_cert", "storage.linstor.client_key":
+			linstorChanged = true
+		default:
+			if strings.HasPrefix(key, "logging.") {
+				fields := strings.Split(key, ".")
+				if len(fields) > 2 {
+					loggingChanges[fields[1]] = struct{}{}
+				}
+			}
 		}
 	}
 
@@ -1000,6 +1013,13 @@ func doApi10UpdateTriggers(d *Daemon, nodeChanged, clusterChanged map[string]str
 		}
 	}
 
+	if linstorChanged {
+		err := d.setupLinstor()
+		if err != nil {
+			return err
+		}
+	}
+
 	// Compile and load the instance placement scriptlet.
 	value, ok = clusterChanged["instances.placement.scriptlet"]
 	if ok {
